@@ -6,7 +6,7 @@ from math import inf
 from pathlib import Path
 from typing import Callable, Dict, List, Optional, Sequence, Union
 
-from mmengine.dist import master_only
+from mmengine.dist import is_main_process
 from mmengine.fileio import FileClient, get_file_backend
 from mmengine.registry import HOOKS
 from mmengine.utils import is_list_of, is_seq_of
@@ -309,7 +309,6 @@ class CheckpointHook(Hook):
 
         return eval_res[key_indicator]
 
-    @master_only
     def _save_checkpoint(self, runner) -> None:
         """Save the current checkpoint and delete outdated checkpoint.
 
@@ -331,6 +330,11 @@ class CheckpointHook(Hook):
             backend_args=self.backend_args,
             **self.args)
 
+        # Model parallel-like training should involve pulling sharded states
+        # from all ranks, but skip the following procedure.
+        if not is_main_process():
+            return
+
         runner.message_hub.update_info(
             'last_ckpt',
             self.file_backend.join_path(self.out_dir, ckpt_filename))
@@ -357,7 +361,6 @@ class CheckpointHook(Hook):
         with open(save_file, 'w') as f:
             f.write(filepath)
 
-    @master_only
     def _save_best_checkpoint(self, runner, metrics) -> None:
         """Save the current checkpoint and delete outdated checkpoint.
 
@@ -405,7 +408,9 @@ class CheckpointHook(Hook):
             best_score = key_score
             runner.message_hub.update_info(best_score_key, best_score)
 
-            if best_ckpt_path and self.file_client.isfile(best_ckpt_path):
+            if best_ckpt_path and \
+               self.file_client.isfile(best_ckpt_path) and \
+               is_main_process():
                 self.file_client.remove(best_ckpt_path)
                 runner.logger.info(
                     f'The previous best checkpoint {best_ckpt_path} '
