@@ -389,6 +389,8 @@ class Runner:
         self.message_hub = self.build_message_hub()
         # visualizer used for writing log or visualizing all kinds of data
         self.visualizer = self.build_visualizer(visualizer)
+        if self.cfg:
+            self.visualizer.add_config(self.cfg)
 
         self._load_from = load_from
         self._resume = resume
@@ -1054,14 +1056,11 @@ class Runner:
             MultiOptimWrapperConstructor which gets parameters passed to
             corresponding optimizers and compose the ``OptimWrapperDict``.
             More details about how to customize OptimizerConstructor can be
-            found at `optimizer-docs`_.
+            found at `optimizer-docs <https://mmengine.readthedocs.io/en/latest/tutorials/optim_wrapper.html>`_.
 
         Returns:
             OptimWrapper: Optimizer wrapper build from ``optimizer_cfg``.
-
-        .. _optimizer-docs:
-           https://mmengine.readthedocs.io/en/latest/tutorials/optimizer.html
-        """
+        """  # noqa: E501
         if isinstance(optim_wrapper, OptimWrapper):
             return optim_wrapper
         if isinstance(optim_wrapper, (dict, ConfigDict, Config)):
