@@ -354,17 +354,25 @@ class WandbVisBackend(BaseVisBackend):
                 updates the current metrics dict with the row argument
                 and metrics won't be saved until `wandb.log` is called
                 with `commit=True`. Default to True.
+        log_code_name: (str, optional) The name of code artifact.
+            By default, the artifact will be named
+            source-$PROJECT_ID-$ENTRYPOINT_RELPATH. See
+            `wandb docs <https://docs.wandb.ai/ref/python/run#log_code>`_
+            for details. Defaults to None.
+            New in version 0.3.0.
     """
 
     def __init__(self,
                  save_dir: str,
                  init_kwargs: Optional[dict] = None,
                  define_metric_cfg: Optional[dict] = None,
-                 commit: Optional[bool] = True):
+                 commit: Optional[bool] = True,
+                 log_code_name: Optional[str] = None):
         super().__init__(save_dir)
         self._init_kwargs = init_kwargs
         self._define_metric_cfg = define_metric_cfg
         self._commit = commit
+        self._log_code_name = log_code_name
 
     def _init_env(self):
         """Setup env for wandb."""
@@ -404,11 +412,8 @@ class WandbVisBackend(BaseVisBackend):
         Args:
             config (Config): The Config object
         """
-        cfg_path = os.path.join(self._wandb.run.dir, 'config.py')
-        config.dump(cfg_path)
-        # Files under run.dir are automatically uploaded,
-        # so no need to manually call save.
-        # self._wandb.save(cfg_path)
+        self._wandb.config.update(dict(config))
+        self._wandb.run.log_code(name=self._log_code_name)
 
     @force_init_env
     def add_image(self,
